@@ -102,7 +102,7 @@
 ##'@export
 
 compare<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
-  if(is(input.seq$data.name, "outcross") || is(input.seq$data.name, "f2"))
+  if(inherits(input.seq$data.name, c("outcross", "f2")))
     return(compare_outcross(input.seq=input.seq,n.best=n.best,tol=tol,verbose=verbose))
   else 
     return(compare_inbred_bc(input.seq=input.seq,n.best=n.best,tol=tol,verbose=verbose))
@@ -113,7 +113,7 @@ compare<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
 compare_outcross<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
 {
   ## checking for correct objects
-  if(!is(input.seq,"sequence"))
+  if(!inherits(input.seq,"sequence"))
     stop(sQuote(deparse(substitute(input.seq)))," is not an object of class 'sequence'")
   if(length(input.seq$seq.num) > 5)
     warning("This operation may take a VERY long time\n")
@@ -166,7 +166,7 @@ compare_outcross<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
           rm.ab<-rem_amb_ph(M=Ph.Init, w=input.seq, seq.num=all.ord[i,])
           Ph.Init <- Ph.Init[rm.ab,]
           Rf.Init <- Rf.Init[rm.ab,]
-          if(is(Ph.Init,"integer")){
+          if(inherits(Ph.Init,"integer")){
             Ph.Init<-matrix(Ph.Init,nrow=1)
             Rf.Init<-matrix(Rf.Init,nrow=1)
           }
@@ -217,7 +217,7 @@ compare_outcross<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
           rm.ab<-rem_amb_ph(M=Ph.Init, w=input.seq, seq.num=all.ord[i,])
           Ph.Init <- Ph.Init[rm.ab,]
           Rf.Init <- Rf.Init[rm.ab,]
-          if(is(Ph.Init,"integer")){
+          if(inherits(Ph.Init,"integer")){
             Ph.Init<-matrix(Ph.Init,nrow=1)
             Rf.Init<-matrix(Rf.Init,nrow=1)
           }
@@ -266,7 +266,7 @@ compare_outcross<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
 compare_inbred_bc<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE) 
 {
   ## checking for correct objects
-  if(!is(input.seq,"sequence"))
+  if(!inherits(input.seq,"sequence"))
     stop(sQuote(deparse(substitute(input.seq)))," is not an object of class 'sequence'")
   if(length(input.seq$seq.num) > 5)
     warning("This operation may take a VERY long time\n")
@@ -308,8 +308,7 @@ compare_inbred_bc<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
                                 rf.vec=rf.temp,
                                 verbose=FALSE,
                                 tol=tol)
-      if(is(input.seq$data.name, "riself") ||
-         is(input.seq$data.name, "risib"))
+      if(inherits(input.seq$data.name, c("riself", "risib")))
         final.map$rf<-adjust_rf_ril(final.map$rf,
                                     type=class(input.seq$data.name)[2],
                                     expand = FALSE)
@@ -344,7 +343,7 @@ compare_inbred_bc<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
 compare_inbred_f2<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE) 
 {
   ## checking for correct objects
-  if(!is(input.seq,"sequence"))
+  if(!inherits(input.seq,"sequence"))
     stop(sQuote(deparse(substitute(input.seq)))," is not an object of class 'sequence'")
   if(length(input.seq$seq.num) > 5)
     warning("This operation may take a VERY long time\n")
@@ -420,7 +419,7 @@ compare_inbred_f2<- function(input.seq, n.best=50, tol=10E-4, verbose=FALSE)
 ##'@method print compare
 print.compare <- function(x,...) {
   FLAG<-0
-  if(!(is(x$data.name, "outcross") | is(x$data.name, "f2"))) FLAG<-1
+  if(!(inherits(x$data.name, c("outcross","f2")))) FLAG<-1
   phases.char <- c("CC","CR","RC","RR")
   n.ord <- max(which(head(x$best.ord.LOD,-1) != -Inf))
   unique.orders <- unique(x$best.ord[1:n.ord,])
