@@ -1,7 +1,4 @@
-## ----knitr_init, echo=FALSE, cache=FALSE---------------------------------
-library(knitr)
-library(rmarkdown)
-
+## ----knitr_init, echo=FALSE, cache=FALSE--------------------------------------
 knitr::opts_chunk$set(collapse = TRUE,
                       comment = "#>",
                       fig.width = 6,
